#!/bin/ksh
#
# Compare ATOVS l1c and l1d from different runs of metopb_run.sh. Re-name the
# "level1" directory after each run.
#
# Usage: ./metopb_compare.sh level1dir_1 level1dir_2
#
# Typically used to compare different releases of AAPP, or different compilers.
# 
# AAPP_PREFIX must be defined as an environment variable
#
################################################################################

if [ $# -lt 2 ]; then
  echo "Usage: ./metopb_compare.sh level1dir_1 level1dir_2"
  exit 0
fi

[ $AAPP_PREFIX ] || { echo "AAPP_PREFIX is not defined"; exit; }
[ -d "$AAPP_PREFIX" ] || { echo "AAPP_PREFIX is not a directory"; exit; }

. "$AAPP_PREFIX/ATOVS_CONF"               #AAPP environment

currentdir=$PWD
dir1=$1
dir2=$2

for dir in $dir1 $dir2; do
  cd $dir
  ln -sf amsua*.l1c aman.l1c
  ln -sf mhs*.l1c ambn.l1c
  ln -sf hirs*.l1c hrsn.l1c
  ln -sf hirs*.l1d hrsn.l1d
  cd $currentdir
done

atovsCompare <<EOF
$dir1
$dir2
EOF

if [ $? = 0 ]; then
  mkdir -p compare
  mv compare*.log compare 2>/dev/null
  echo "atovsCompare results are in $PWD/compare"
else
  echo "atovsCompare failed"
fi
