#!/bin/ksh
#
# NOAA-19 test case

[ $AAPP_PREFIX ] || { echo "AAPP_PREFIX is not defined"; exit; }
[ -d "$AAPP_PREFIX" ] || { echo "AAPP_PREFIX is not a directory"; exit; }

export DIR_NAVIGATION=$PWD/orbelems       #Over-ride default in ATOVS_ENV
export PAR_NAVIGATION_DEFAULT_LISTESAT='noaa19'
export PAR_NAVIGATION_DEFAULT_LISTEBUL='tle'    #set up for 2-line elements

. "$AAPP_PREFIX/ATOVS_CONF"               #AAPP environment

if [ "$RUN_MAIA" = "yes" ]; then
  export DIR_FORECAST=$PWD/forecast
  export MAIA4_USE_GFS="yes"
  mkdir -p $DIR_FORECAST
else
  echo "Not running MAIA (export RUN_MAIA=yes to change it)"
fi

export WRK=$PWD/work
level1=$PWD/level1
if [ -d $level1 ]; then
  rm -rf ${level1}_previous
  echo "re-naming the existing level 1 directory to ${level1}_previous"
  mv $level1 ${level1}_previous
fi

mkdir -p $WRK $level1
cd $WRK

instr="AMSU-A MHS HIRS AVHRR"
grids="HIRS"

time AAPP_RUN_NOAA -Y 2020 -i "$instr" -g "$grids" $PWD/../hrpt/NO19_59160_31Jul20_0741.dat >noaa19.out 2>&1
status=$?
if [ $status != 0 ]; then
  echo "AAPP_RUN_NOAA failed"
  exit 1
else
  outfiles=$(ls *.l1b *.l1c *.l1d 2>/dev/null)
  for file in $outfiles; do
    if [ -s $file ] && [ $file != hrpt.l1b.l1c ]; then
      mv $file ../level1
    else
      rm $file
    fi
  done
  if [ "$outfiles" ]; then
    echo "AAPP_RUN_NOAA ended: output in $level1"
  else
    echo "No output files were generated"
  fi
fi

cd $level1
has_hdf5=Y
for file in $(ls amsu*.l1c mhs*.l1c hirs*.l1c hirs*.l1d); do
  if [ $has_hdf5=Y ]; then
    convert_to_hdf5 $file || has_hdf5=N
  fi
done

if [ $has_hdf5 ]; then
  echo "Converted l1c files to hdf5"
else
  echo "Have not converted l1c files to hdf5"
fi
